#!/bin/sh

set -eo pipefail

# This script expects the following env vars to be set :
# PEM_KEY_FILE : the path of the PEM private key (must exists)
# PEM_CERT_FILE : the path of the PEM certificate (must exists)
# (both PEM_KEY_FILE and PEM_CERT_FILE can refer to the same file if it contains both)
# P12_FILE : the path of the PKCS12 bundle to create

if [ -n "${PEM_KEY_FILE}" -a -f "${PEM_KEY_FILE}" -a -n "${PEM_CERT_FILE}" -a -f "${PEM_CERT_FILE}" -a -n "${P12_FILE}" ]; then
  if [ ! -f "${P12_FILE}" -o "${PEM_KEY_FILE}" -nt "${P12_FILE}" ]; then
    echo "Converting PEM files ${PEM_KEY_FILE} and ${PEM_CERT_FILE} to PKCS12 format ${P12_FILE}"
    openssl pkcs12 -export -out ${P12_FILE} -in ${PEM_CERT_FILE} -inkey ${PEM_KEY_FILE} -passout pass:password
    chmod 640 ${P12_FILE}
  else
    echo "${P12_FILE} already exist and is newer than ${PEM_KEY_FILE}"
  fi
fi
