#!/bin/sh

set -euo pipefail

if [ "${PG_INIT:-true}" = "false" ]; then
  echo "PG_INIT is set to false, skipping initdb"
  exit 0
fi

if [ -z "${PG_USER}" ]; then
  echo "PG_USER must be set"
  exit 1
fi

if [ -z "${PG_PASSWORD}" ]; then
  echo "PG_PASSWORD must be set"
  exit 1
fi

if [ \! -f "${PGDATA}/PG_VERSION" ]; then
  source /etc/os-release
  echo "Empty postgres dir, initialization"
  if [ "${ID}" = "alpine" ]; then
    initdb --icu-locale=${LANG} --data-checksums --encoding=UTF8 --locale-provider=icu --pwfile=<(echo "${PG_PASSWORD}") ${PGDATA}
  else
    initdb --data-checksums --encoding=UTF8 --pwfile=<(echo "${PG_PASSWORD}") ${PGDATA}
  fi
  echo "Initial pg_hba.conf configuration"
  cat <<_EOF > ${PGDATA}/pg_hba.conf
local all all           peer
host  all all 0.0.0.0/0 scram-sha-256
_EOF
fi

