#!/bin/sh

set -eo pipefail

get_max_mem(){
  if [ -n "${NOMAD_MEMORY_LIMIT}" ]; then
    echo ${NOMAD_MEMORY_LIMIT}
  elif [ -e /sys/fs/cgroup/memory.max ]; then
    # Read /sys/fs/cgroup/memory.max
    MAX=$(cat /sys/fs/cgroup/memory.max)
    # If it's "max", then the container has no limit, and we must detect the available RAM
    if [ "${MAX}" = "max" ]; then
      echo $(($(cat /proc/meminfo | grep MemTotal | sed -E 's/MemTotal:\s+([0-9]+)\s+kB/\1/')/1024))
    else
      echo $(($(cat /sys/fs/cgroup/memory.max)/1024/1024))
    fi
  elif [ -e /sys/fs/cgroup/memory/memory.max_usage_in_bytes ]; then
    echo $(($(/sys/fs/cgroup/memory/memory.max_usage_in_bytes)/1024/1024))
  else
    echo $(($(cat /proc/meminfo | grep MemTotal | sed -E 's/MemTotal:\s+([0-9]+)\s+kB/\1/')/1024))
  fi
}

if [ \! -e ${PGDATA}/${PG_CONFFILE} ]; then
  echo "${PGDATA}/${PG_CONFFILE} doesn't exist (yet ?). Skipping config from env"
  exit 0
fi

for CONF in $(printenv | grep -E '^PG_CONF_' | sed -E 's/PG_CONF_([^=]+)=.*/\1/'); do
  VALUE=$(printenv PG_CONF_${CONF})
  if [ "${VALUE}" = "" ]; then
    echo "Removing ${CONF}"
    sed -i -E "s|^(${CONF}\s*=.*)|# \1|g" ${PGDATA}/${PG_CONFFILE}
  else
    echo "Found ${CONF} = ${VALUE} from env var"

    # Allow some memory related settings to be expressed as a %
    if echo ${CONF} | grep -q -E "^(shared_buffers|effective_cache_size|maintenance_work_mem|wal_buffers|work_mem)$"; then
      if echo ${VALUE} | grep -q -E "[0-9]+%$"; then
        PERCENT=$(echo $VALUE | sed -E 's|%$||')
        MAX_MEM=$(get_max_mem)
        VALUE=$((${MAX_MEM}*${PERCENT}/100))MB
      fi
    fi

    if grep -q -E "^#?\s*${CONF}\s*=" ${PGDATA}/${PG_CONFFILE}; then
      echo "Updating ${CONF} to ${VALUE}"
      sed -i -E "s|^#?\s*${CONF}\s*=.*|${CONF} = ${VALUE}|g" ${PGDATA}/${PG_CONFFILE}
    else
      echo "Adding ${CONF} with value ${VALUE}"
      echo "${CONF} = ${VALUE}" >> ${PGDATA}/${PG_CONFFILE}
    fi
  fi
done

